Macro tezos_smart_rollup_debug::debug_str
source · macro_rules! debug_str { ($host: expr, $msg: expr) => { ... }; }
Write a string to the debug log.
While this is less powerful than debug_msg (which supports format strings),
it does not require an allocator in order to be used.
Just like debug_msg, you can use it with any variable implementing the Runtime
trait.
use tezos_smart_rollup_debug::debug_str;
use tezos_smart_rollup_host::runtime::Runtime;
fn do_something(host: &impl Runtime) {
debug_str!(host, "Simple constant string");
}